const path = require("path");
const name = "wanda-adm";
const devServerPort = 28888;
const stageServerPort = 28889;
module.exports = {
    // TODO: Remember to change publicPath to fit your need
    publicPath: process.env.NODE_ENV === "production" ? "/wanda-adm/" : "/",
    lintOnSave: process.env.NODE_ENV === "development",
    productionSourceMap: false,
    devServer: {
        port: devServerPort,
        open: true,
        overlay: {
            warning: false,
            errors: true
        },
        progress: false,
        proxy: {
            [process.env.VUE_APP_BASE_API]: {
                target: `http://127.0.0.1:${stageServerPort}/mock-api/v1`,
                changeOrigin: true, // needed for virtual hosted sites
                ws: true, // proxy websockets
                pathRewrite: {
                    ["^" + process.env.VUE_APP_BASE_API]: ""
                }
            },
            "/datacenter": {
                target: "http://60.205.177.43:28888",
                changeOrigin: true,
                secure: false
            },
            "/modelapi": {
                target: "http://39.102.40.239:8080/",
                changeOrigin: true,
                pathRewrite: {
                    "^/modelapi": "/revit-algorithm"
                }
            }
        }
    },

    pluginOptions: {
        "style-resources-loader": {
            preProcessor: "scss",
            patterns: [
                path.resolve(__dirname, "src/styles/_variables.scss"),
                path.resolve(__dirname, "src/styles/_mixins.scss")
            ]
        }
    },
    chainWebpack(config) {
        // provide the app's title in html-webpack-plugin's options list so that
        // it can be accessed in index.html to inject the correct title.
        // https://cli.vuejs.org/guide/webpack.html#modifying-options-of-a-plugin
        config.plugin("html").tap(args => {
            args[0].title = name;
            return args;
        });
    }
};
